# myke

> None

| Links         |                        |
|---------------|------------------------|
| Code Repo     | https://www.github.com/fresh2dev/myke           |
| Mirror Repo   | https://www.Fresh2.dev/code/r/myke        |
| Documentation | https://www.Fresh2.dev/code/r/myke/i           |
| Changelog     | https://www.Fresh2.dev/code/r/myke/i/changelog |
| License       | https://www.Fresh2.dev/code/r/myke/i/license   |
| Funding       | https://www.Fresh2.dev/funding        |

[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.github.com/fresh2dev/myke/releases)
[![GitHub Release Date](https://img.shields.io/github/release-date/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.github.com/fresh2dev/myke/releases)
[![License](https://img.shields.io/github/license/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.Fresh2.dev/code/r/myke/i/license)
[![GitHub issues](https://img.shields.io/github/issues-raw/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.github.com/fresh2dev/myke/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr-raw/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.github.com/fresh2dev/myke/pulls)
[![GitHub Repo stars](https://img.shields.io/github/stars/fresh2dev/myke?color=blue&style=for-the-badge)](https://star-history.com/#fresh2dev/myke&Date)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/myke?color=blue&style=for-the-badge)](https://pypi.org/project/myke)
[![Docker Pulls](https://img.shields.io/docker/pulls/fresh2dev/myke?color=blue&style=for-the-badge)](https://hub.docker.com/r/fresh2dev/myke)
[![Docs Website](https://img.shields.io/website?down_message=unavailable&label=docs&style=for-the-badge&up_color=blue&up_message=available&url=https://www.Fresh2.dev/code/r/myke/i)](https://www.Fresh2.dev/code/r/myke/i)
[![Coverage Website](https://img.shields.io/website?down_message=unavailable&label=coverage&style=for-the-badge&up_color=blue&up_message=available&url=https://www.Fresh2.dev/code/r/myke/i/tests/coverage)](https://www.Fresh2.dev/code/r/myke/i/tests/coverage)
[![Funding](https://img.shields.io/badge/funding-%24%24%24-blue?style=for-the-badge)](https://www.Fresh2.dev/funding)

*Brought to you by...*

<a href="https://www.fresh2.dev"><img src="https://img.fresh2.dev/fresh2dev.svg" style="filter: invert(50%);"></img></a>

---
